@@ -20,21 +20,29 @@ use std::fmt;
 /// An internal error type for content related errors.
 #[derive(Debug)]
 pub enum Error {
-    FailedParsingYaml,
+    FailedParsingYaml(std::path::PathBuf),
     UnexpectedDataType,
     #[cfg(feature = "_cargo_insta_internal")]
     MissingField,
+    #[cfg(feature = "_cargo_insta_internal")]
+    FileIo(std::io::Error, std::path::PathBuf),
 }
 
 impl fmt::Display for Error {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
-            Self::FailedParsingYaml => f.write_str("Failed parsing the provided YAML text"),
-            Self::UnexpectedDataType => {
+            Error::FailedParsingYaml(p) => {
+                f.write_str(format!("Failed parsing the YAML from {:?}", p.display()).as_str())
+            }
+            Error::UnexpectedDataType => {
                 f.write_str("The present data type wasn't what was expected")
             }
             #[cfg(feature = "_cargo_insta_internal")]
-            Self::MissingField => f.write_str("A required field was missing"),
+            Error::MissingField => f.write_str("A required field was missing"),
+            #[cfg(feature = "_cargo_insta_internal")]
+            Error::FileIo(e, p) => {
+                f.write_str(format!("File error for {:?}: {}", p.display(), e).as_str())
+            }
         }
     }
 }
