@@ -243,9 +243,9 @@ where
         Ok(Content::None)
     }
 
-    fn serialize_some<T: ?Sized>(self, value: &T) -> Result<Content, E>
+    fn serialize_some<T>(self, value: &T) -> Result<Content, E>
     where
-        T: Serialize,
+        T: Serialize + ?Sized,
     {
         Ok(Content::Some(Box::new(value.serialize(self)?)))
     }
@@ -267,13 +267,9 @@ where
         Ok(Content::UnitVariant(name, variant_index, variant))
     }
 
-    fn serialize_newtype_struct<T: ?Sized>(
-        self,
-        name: &'static str,
-        value: &T,
-    ) -> Result<Content, E>
+    fn serialize_newtype_struct<T>(self, name: &'static str, value: &T) -> Result<Content, E>
     where
-        T: Serialize,
+        T: Serialize + ?Sized,
     {
         Ok(Content::NewtypeStruct(
             name,
@@ -281,7 +277,7 @@ where
         ))
     }
 
-    fn serialize_newtype_variant<T: ?Sized>(
+    fn serialize_newtype_variant<T>(
         self,
         name: &'static str,
         variant_index: u32,
@@ -289,7 +285,7 @@ where
         value: &T,
     ) -> Result<Content, E>
     where
-        T: Serialize,
+        T: Serialize + ?Sized,
     {
         Ok(Content::NewtypeVariant(
             name,
@@ -386,9 +382,9 @@ where
     type Ok = Content;
     type Error = E;
 
-    fn serialize_element<T: ?Sized>(&mut self, value: &T) -> Result<(), E>
+    fn serialize_element<T>(&mut self, value: &T) -> Result<(), E>
     where
-        T: Serialize,
+        T: Serialize + ?Sized,
     {
         let value = value.serialize(ContentSerializer::<E>::new())?;
         self.elements.push(value);
@@ -412,9 +408,9 @@ where
     type Ok = Content;
     type Error = E;
 
-    fn serialize_element<T: ?Sized>(&mut self, value: &T) -> Result<(), E>
+    fn serialize_element<T>(&mut self, value: &T) -> Result<(), E>
     where
-        T: Serialize,
+        T: Serialize + ?Sized,
     {
         let value = value.serialize(ContentSerializer::<E>::new())?;
         self.elements.push(value);
@@ -439,9 +435,9 @@ where
     type Ok = Content;
     type Error = E;
 
-    fn serialize_field<T: ?Sized>(&mut self, value: &T) -> Result<(), E>
+    fn serialize_field<T>(&mut self, value: &T) -> Result<(), E>
     where
-        T: Serialize,
+        T: Serialize + ?Sized,
     {
         let value = value.serialize(ContentSerializer::<E>::new())?;
         self.fields.push(value);
@@ -468,9 +464,9 @@ where
     type Ok = Content;
     type Error = E;
 
-    fn serialize_field<T: ?Sized>(&mut self, value: &T) -> Result<(), E>
+    fn serialize_field<T>(&mut self, value: &T) -> Result<(), E>
     where
-        T: Serialize,
+        T: Serialize + ?Sized,
     {
         let value = value.serialize(ContentSerializer::<E>::new())?;
         self.fields.push(value);
@@ -500,18 +496,18 @@ where
     type Ok = Content;
     type Error = E;
 
-    fn serialize_key<T: ?Sized>(&mut self, key: &T) -> Result<(), E>
+    fn serialize_key<T>(&mut self, key: &T) -> Result<(), E>
     where
-        T: Serialize,
+        T: Serialize + ?Sized,
     {
         let key = key.serialize(ContentSerializer::<E>::new())?;
         self.key = Some(key);
         Ok(())
     }
 
-    fn serialize_value<T: ?Sized>(&mut self, value: &T) -> Result<(), E>
+    fn serialize_value<T>(&mut self, value: &T) -> Result<(), E>
     where
-        T: Serialize,
+        T: Serialize + ?Sized,
     {
         let key = self
             .key
@@ -526,10 +522,10 @@ where
         Ok(Content::Map(self.entries))
     }
 
-    fn serialize_entry<K: ?Sized, V: ?Sized>(&mut self, key: &K, value: &V) -> Result<(), E>
+    fn serialize_entry<K, V>(&mut self, key: &K, value: &V) -> Result<(), E>
     where
-        K: Serialize,
-        V: Serialize,
+        K: Serialize + ?Sized,
+        V: Serialize + ?Sized,
     {
         let key = key.serialize(ContentSerializer::<E>::new())?;
         let value = value.serialize(ContentSerializer::<E>::new())?;
@@ -551,9 +547,9 @@ where
     type Ok = Content;
     type Error = E;
 
-    fn serialize_field<T: ?Sized>(&mut self, key: &'static str, value: &T) -> Result<(), E>
+    fn serialize_field<T>(&mut self, key: &'static str, value: &T) -> Result<(), E>
     where
-        T: Serialize,
+        T: Serialize + ?Sized,
     {
         let value = value.serialize(ContentSerializer::<E>::new())?;
         self.fields.push((key, value));
@@ -580,9 +576,9 @@ where
     type Ok = Content;
     type Error = E;
 
-    fn serialize_field<T: ?Sized>(&mut self, key: &'static str, value: &T) -> Result<(), E>
+    fn serialize_field<T>(&mut self, key: &'static str, value: &T) -> Result<(), E>
     where
-        T: Serialize,
+        T: Serialize + ?Sized,
     {
         let value = value.serialize(ContentSerializer::<E>::new())?;
         self.fields.push((key, value));
