@@ -1,5 +1,5 @@
 use std::collections::BTreeMap;
-use std::io::{self, Write};
+use std::io::Write;
 use std::path::{Path, PathBuf};
 use std::sync::{Arc, Mutex};
 use std::{env, fmt, fs};
@@ -69,7 +69,6 @@ pub enum SnapshotUpdate {
 #[derive(Debug)]
 pub enum Error {
     Deserialize(crate::content::Error),
-    Io(std::io::Error),
     Env(&'static str),
     #[allow(unused)]
     Config(&'static str),
@@ -79,7 +78,6 @@ impl fmt::Display for Error {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
             Error::Deserialize(_) => write!(f, "failed to deserialize tool config"),
-            Error::Io(_) => write!(f, "io error while reading tool config"),
             Error::Env(var) => write!(f, "invalid value for env var '{}'", var),
             Error::Config(var) => write!(f, "invalid value for config '{}'", var),
         }
@@ -90,7 +88,6 @@ impl std::error::Error for Error {
     fn source(&self) -> Option<&(dyn std::error::Error + 'static)> {
         match self {
             Error::Deserialize(ref err) => Some(err),
-            Error::Io(ref err) => Some(err),
             _ => None,
         }
     }
@@ -101,6 +98,7 @@ impl std::error::Error for Error {
 pub struct ToolConfig {
     force_update_snapshots: bool,
     force_pass: bool,
+    require_full_match: bool,
     output: OutputBehavior,
     snapshot_update: SnapshotUpdate,
     #[cfg(feature = "glob")]
@@ -132,25 +130,47 @@ impl ToolConfig {
         let mut cfg = None;
         for choice in &[".config/insta.yaml", "insta.yaml", ".insta.yaml"] {
             let path = workspace_dir.join(choice);
-            match fs::read_to_string(path) {
+            match fs::read_to_string(&path) {
                 Ok(s) => {
-                    cfg = Some(yaml::parse_str(&s).map_err(Error::Deserialize)?);
+                    cfg = Some(yaml::parse_str(&s, &path).map_err(Error::Deserialize)?);
                     break;
                 }
-                Err(err) if matches!(err.kind(), io::ErrorKind::NotFound) => continue,
-                Err(err) => return Err(Error::Io(err)),
+                // ideally we would not swallow all errors here but unfortunately there are
+                // some cases where we cannot detect the error properly.
+                // Eg we can see NotADirectory here as kind, but on stable rust it cannot
+                // be matched on.
+                Err(_) => continue,
             }
         }
         let cfg = cfg.unwrap_or_else(|| Content::Map(Default::default()));
 
+        // support for the deprecated environment variable.  This is implemented in a way that
+        // cargo-insta can support older and newer insta versions alike.  It will set both
+        // variables.  However if only `INSTA_FORCE_UPDATE_SNAPSHOTS` is set, we will emit
+        // a deprecation warning.
+        if env::var("INSTA_FORCE_UPDATE").is_err() {
+            if let Ok("1") = env::var("INSTA_FORCE_UPDATE_SNAPSHOTS").as_deref() {
+                eprintln!("INSTA_FORCE_UPDATE_SNAPSHOTS is deprecated, use INSTA_FORCE_UPDATE");
+                env::set_var("INSTA_FORCE_UPDATE", "1");
+            }
+        }
+
         Ok(ToolConfig {
-            force_update_snapshots: match env::var("INSTA_FORCE_UPDATE_SNAPSHOTS").as_deref() {
+            force_update_snapshots: match env::var("INSTA_FORCE_UPDATE").as_deref() {
                 Err(_) | Ok("") => resolve(&cfg, &["behavior", "force_update"])
                     .and_then(|x| x.as_bool())
                     .unwrap_or(false),
                 Ok("0") => false,
                 Ok("1") => true,
-                _ => return Err(Error::Env("INSTA_FORCE_UPDATE_SNAPSHOTS")),
+                _ => return Err(Error::Env("INSTA_FORCE_UPDATE")),
+            },
+            require_full_match: match env::var("INSTA_REQUIRE_FULL_MATCH").as_deref() {
+                Err(_) | Ok("") => resolve(&cfg, &["behavior", "require_full_match"])
+                    .and_then(|x| x.as_bool())
+                    .unwrap_or(false),
+                Ok("0") => false,
+                Ok("1") => true,
+                _ => return Err(Error::Env("INSTA_REQUIRE_FULL_MATCH")),
             },
             force_pass: match env::var("INSTA_FORCE_PASS").as_deref() {
                 Err(_) | Ok("") => resolve(&cfg, &["behavior", "force_pass"])
@@ -250,6 +270,11 @@ impl ToolConfig {
         self.force_update_snapshots
     }
 
+    /// Should we fail if metadata doesn't match?
+    pub fn require_full_match(&self) -> bool {
+        self.require_full_match
+    }
+
     /// Is insta instructed to fail in tests?
     pub fn force_pass(&self) -> bool {
         self.force_pass
@@ -368,10 +393,11 @@ pub fn get_cargo_workspace(manifest_dir: &str) -> Arc<PathBuf> {
             .current_dir(manifest_dir)
             .output()
             .unwrap();
-            let docs =
-                yaml_rust::YamlLoader::load_from_str(std::str::from_utf8(&output.stdout).unwrap())
-                    .unwrap();
-            let manifest = docs.get(0).expect("Unable to parse cargo manifest");
+            let docs = crate::content::yaml::vendored::yaml::YamlLoader::load_from_str(
+                std::str::from_utf8(&output.stdout).unwrap(),
+            )
+            .unwrap();
+            let manifest = docs.first().expect("Unable to parse cargo manifest");
             let workspace_root = PathBuf::from(manifest["workspace_root"].as_str().unwrap());
             Arc::new(workspace_root)
         };
@@ -414,7 +440,6 @@ impl std::str::FromStr for UnreferencedSnapshots {
 pub fn memoize_snapshot_file(snapshot_file: &Path) {
     if let Ok(path) = env::var("INSTA_SNAPSHOT_REFERENCES_FILE") {
         let mut f = fs::OpenOptions::new()
-            .write(true)
             .append(true)
             .create(true)
             .open(path)
