@@ -6,7 +6,7 @@ use std::fmt;
 use crate::content::Content;
 
 #[derive(Debug)]
-pub struct SelectorParseError(pest::error::Error<Rule>);
+pub struct SelectorParseError(Box<pest::error::Error<Rule>>);
 
 impl SelectorParseError {
     /// Return the column of where the error occurred.
@@ -166,6 +166,27 @@ pub fn sorted_redaction() -> Redaction {
     dynamic_redaction(sort)
 }
 
+/// Creates a redaction that rounds floating point numbers to a given
+/// number of decimal places.
+///
+/// ```rust
+/// # use insta::{Settings, rounded_redaction};
+/// # let mut settings = Settings::new();
+/// settings.add_redaction(".sum", rounded_redaction(2));
+/// ```
+#[cfg_attr(docsrs, doc(cfg(feature = "redactions")))]
+pub fn rounded_redaction(decimals: usize) -> Redaction {
+    dynamic_redaction(move |value: Content, _path: ContentPath| -> Content {
+        let f = match value.resolve_inner() {
+            Content::F32(f) => *f as f64,
+            Content::F64(f) => *f,
+            _ => return value,
+        };
+        let x = 10f64.powf(decimals as f64);
+        Content::F64((f * x).round() / x)
+    })
+}
+
 impl Redaction {
     /// Performs the redaction of the value at the given path.
     fn redact(&self, value: Content, path: &[PathItem]) -> Content {
@@ -244,6 +265,7 @@ pub struct Selector<'a> {
 impl<'a> Selector<'a> {
     pub fn parse(selector: &'a str) -> Result<Selector<'a>, SelectorParseError> {
         let pair = SelectParser::parse(Rule::selectors, selector)
+            .map_err(Box::new)
             .map_err(SelectorParseError)?
             .next()
             .unwrap();
@@ -262,11 +284,13 @@ impl<'a> Selector<'a> {
                     Rule::wildcard => Segment::Wildcard,
                     Rule::deep_wildcard => {
                         if have_deep_wildcard {
-                            return Err(SelectorParseError(pest::error::Error::new_from_span(
-                                pest::error::ErrorVariant::CustomError {
-                                    message: "deep wildcard used twice".into(),
-                                },
-                                segment_pair.as_span(),
+                            return Err(SelectorParseError(Box::new(
+                                pest::error::Error::new_from_span(
+                                    pest::error::ErrorVariant::CustomError {
+                                        message: "deep wildcard used twice".into(),
+                                    },
+                                    segment_pair.as_span(),
+                                ),
                             )));
                         }
                         have_deep_wildcard = true;
