@@ -344,8 +344,7 @@ impl<'a> SnapshotAssertionContext<'a> {
         // let's just make sure there are no more pending files lingering
         // around.
         if let Some(ref snapshot_file) = self.snapshot_file {
-            let mut snapshot_file = snapshot_file.clone();
-            snapshot_file.set_extension("snap.new");
+            let snapshot_file = snapshot_file.clone().with_extension("snap.new");
             fs::remove_file(snapshot_file).ok();
         }
 
@@ -666,8 +665,19 @@ pub fn assert_snapshot(
         }
     });
 
-    // pass if the snapshots are missing
-    if ctx.old_snapshot.as_ref().map(|x| x.contents()) == Some(new_snapshot.contents()) {
+    let pass = ctx
+        .old_snapshot
+        .as_ref()
+        .map(|x| {
+            if tool_config.require_full_match() {
+                x.matches_fully(&new_snapshot)
+            } else {
+                x.matches(&new_snapshot)
+            }
+        })
+        .unwrap_or(false);
+
+    if pass {
         ctx.cleanup_passing()?;
 
         if tool_config.force_update_snapshots() {
@@ -686,7 +696,12 @@ pub fn assert_snapshot(
 /// Test snapshots in doctests.
 ///
 /// ```
-/// insta::assert_debug_snapshot!("named", vec![1, 2, 3, 4, 5]);
+/// // this is only working on newer rust versions
+/// extern crate rustc_version;
+/// use rustc_version::{Version, version};
+/// if version().unwrap() > Version::parse("1.72.0").unwrap() {
+///     insta::assert_debug_snapshot!("named", vec![1, 2, 3, 4, 5]);
+/// }
 /// ```
 ///
 /// ```should_panic
