@@ -39,12 +39,13 @@ impl PendingInlineSnapshot {
 
     #[cfg(feature = "_cargo_insta_internal")]
     pub fn load_batch(p: &Path) -> Result<Vec<PendingInlineSnapshot>, Box<dyn Error>> {
-        let contents = fs::read_to_string(p)?;
+        let contents =
+            fs::read_to_string(p).map_err(|e| content::Error::FileIo(e, p.to_path_buf()))?;
 
         let mut rv: Vec<Self> = contents
             .lines()
             .map(|line| {
-                let value = yaml::parse_str(line)?;
+                let value = yaml::parse_str(line, p)?;
                 Self::from_content(value)
             })
             .collect::<Result<_, Box<dyn Error>>>()?;
@@ -128,11 +129,12 @@ impl PendingInlineSnapshot {
 }
 
 /// Snapshot metadata information.
-#[derive(Debug, Default, Clone)]
+#[derive(Debug, Default, Clone, PartialEq)]
 pub struct MetaData {
     /// The source file (relative to workspace root).
     pub(crate) source: Option<String>,
-    /// The source line if available.
+    /// The source line, if available. This is used by pending snapshots, but trimmed
+    /// before writing to the final `.snap` files in [`MetaData::trim_for_persistence`].
     pub(crate) assertion_line: Option<u32>,
     /// Optional human readable (non formatted) snapshot description.
     pub(crate) description: Option<String>,
@@ -245,7 +247,8 @@ impl MetaData {
         Content::Struct("MetaData", fields)
     }
 
-    /// Trims the metadata for persistence.
+    /// Trims the metadata of fields that we don't save to `.snap` files; we
+    /// only use for display while reviewing
     fn trim_for_persistence(&self) -> Cow<'_, MetaData> {
         if self.assertion_line.is_some() {
             let mut rv = self.clone();
@@ -286,7 +289,7 @@ impl Snapshot {
                     break;
                 }
             }
-            let content = yaml::parse_str(&buf)?;
+            let content = yaml::parse_str(&buf, p)?;
             MetaData::from_content(content)?
         // legacy format
         } else {
@@ -322,31 +325,11 @@ impl Snapshot {
             buf.push_str(&line);
         }
 
-        let module_name = p
-            .file_name()
-            .unwrap()
-            .to_str()
-            .unwrap_or("")
-            .split("__")
-            .next()
-            .unwrap_or("<unknown>")
-            .to_string();
-
-        let snapshot_name = p
-            .file_name()
-            .unwrap()
-            .to_str()
-            .unwrap_or("")
-            .split('.')
-            .next()
-            .unwrap_or("")
-            .splitn(2, "__")
-            .nth(1)
-            .map(|x| x.to_string());
+        let (snapshot_name, module_name) = names_of_path(p);
 
         Ok(Snapshot::from_components(
             module_name,
-            snapshot_name,
+            Some(snapshot_name),
             metadata,
             buf.into(),
         ))
@@ -434,9 +417,20 @@ impl Snapshot {
         &self.snapshot
     }
 
+    /// Snapshot contents match another snapshot's.
+    pub fn matches(&self, other: &Snapshot) -> bool {
+        self.contents() == other.contents()
+    }
+
+    /// Snapshot contents _and_ metadata match another snapshot's.
+    pub fn matches_fully(&self, other: &Snapshot) -> bool {
+        self.matches(other)
+            && self.metadata.trim_for_persistence() == other.metadata.trim_for_persistence()
+    }
+
     /// The snapshot contents as a &str
     pub fn contents_str(&self) -> &str {
-        &self.snapshot.0
+        self.snapshot.as_str()
     }
 
     fn serialize_snapshot(&self, md: &MetaData) -> String {
@@ -490,8 +484,7 @@ impl Snapshot {
     /// If the existing snapshot matches the new file, then `None` is returned, otherwise
     /// the name of the new snapshot file.
     pub(crate) fn save_new(&self, path: &Path) -> Result<Option<PathBuf>, Box<dyn Error>> {
-        let mut new_path = path.to_path_buf();
-        new_path.set_extension("snap.new");
+        let new_path = path.to_path_buf().with_extension("snap.new");
         if self.save_with_metadata(&new_path, Some(path), &self.metadata)? {
             Ok(Some(new_path))
         } else {
@@ -510,6 +503,13 @@ impl SnapshotContents {
         SnapshotContents(get_inline_snapshot_value(value))
     }
 
+    /// Returns the snapshot contents as string with surrounding whitespace removed.
+    pub fn as_str(&self) -> &str {
+        self.0
+            .trim_start_matches(|x| x == '\r' || x == '\n')
+            .trim_end()
+    }
+
     pub fn to_inline(&self, indentation: usize) -> String {
         let contents = &self.0;
         let mut out = String::new();
@@ -576,7 +576,7 @@ impl From<SnapshotContents> for String {
 
 impl PartialEq for SnapshotContents {
     fn eq(&self, other: &Self) -> bool {
-        self.0.trim_end() == other.0.trim_end()
+        self.as_str() == other.as_str()
     }
 }
 
@@ -612,6 +612,53 @@ fn normalize_inline_snapshot(snapshot: &str) -> String {
         .join("\n")
 }
 
+/// Extracts the module and snapshot name from a snapshot path
+fn names_of_path(path: &Path) -> (String, String) {
+    // The final part of the snapshot file name is the test name; the
+    // initial parts are the module name
+    let parts: Vec<&str> = path
+        .file_stem()
+        .unwrap()
+        .to_str()
+        .unwrap_or("")
+        .rsplitn(2, "__")
+        .collect();
+
+    match parts.as_slice() {
+        [snapshot_name, module_name] => (snapshot_name.to_string(), module_name.to_string()),
+        [snapshot_name] => (snapshot_name.to_string(), String::new()),
+        _ => (String::new(), "<unknown>".to_string()),
+    }
+}
+
+#[test]
+fn test_names_of_path() {
+    assert_debug_snapshot!(
+        names_of_path(Path::new("/src/snapshots/insta_tests__tests__name_foo.snap")), @r###"
+    (
+        "name_foo",
+        "insta_tests__tests",
+    )
+    "###
+    );
+    assert_debug_snapshot!(
+        names_of_path(Path::new("/src/snapshots/name_foo.snap")), @r###"
+    (
+        "name_foo",
+        "",
+    )
+    "###
+    );
+    assert_debug_snapshot!(
+        names_of_path(Path::new("foo/src/snapshots/go1.20.5.snap")), @r###"
+    (
+        "go1.20.5",
+        "",
+    )
+    "###
+    );
+}
+
 /// Helper function that returns the real inline snapshot value from a given
 /// frozen value string.  If the string starts with the '⋮' character
 /// (optionally prefixed by whitespace) the alternative serialization format
@@ -878,3 +925,34 @@ fn test_inline_snapshot_value_newline() {
     // https://github.com/mitsuhiko/insta/issues/39
     assert_eq!(get_inline_snapshot_value("\n"), "");
 }
+
+#[test]
+fn test_parse_yaml_error() {
+    use std::env::temp_dir;
+    let mut temp = temp_dir();
+    temp.push("bad.yaml");
+    let mut f = fs::File::create(temp.clone()).unwrap();
+
+    let invalid = r#"---
+    This is invalid yaml:
+     {
+        {
+    ---
+    "#;
+
+    f.write_all(invalid.as_bytes()).unwrap();
+
+    let error = format!("{}", Snapshot::from_file(temp.as_path()).unwrap_err());
+    assert!(error.contains("Failed parsing the YAML from"));
+    assert!(error.contains("/bad.yaml"));
+}
+
+/// Check that snapshots don't take ownership of the value
+#[test]
+fn test_ownership() {
+    // Range is non-copy
+    use std::ops::Range;
+    let r = Range { start: 0, end: 10 };
+    assert_debug_snapshot!(r, @"0..10");
+    assert_debug_snapshot!(r, @"0..10");
+}
