@@ -86,6 +86,51 @@ fn test_with_random_value_and_trailing_comma() {
     });
 }
 
+#[cfg(feature = "yaml")]
+#[test]
+fn test_with_random_value_and_match_comma() {
+    assert_yaml_snapshot!(
+        &User {
+            id: 11,
+            username: "john_doe".to_string(),
+            email: Email("john@example.com".to_string()),
+            extra: "".to_string(),
+        },
+        match .. {
+            ".id" => "[id]",
+        }
+    );
+    assert_yaml_snapshot!(
+        &User {
+            id: 11,
+            username: "john_doe".to_string(),
+            email: Email("john@example.com".to_string()),
+            extra: "".to_string(),
+        },
+        match .. {
+            ".id" => "[id]",
+        }, // comma here
+    );
+    assert_yaml_snapshot!(
+        &User {
+            id: 11,
+            username: "john_doe".to_string(),
+            email: Email("john@example.com".to_string()),
+            extra: "".to_string(),
+        },
+        match .. {
+            ".id" => "[id]",
+        },
+        @r###"
+        ---
+        id: "[id]"
+        username: john_doe
+        email: john@example.com
+        extra: ""
+        "###, // comma here
+    );
+}
+
 #[cfg(feature = "csv")]
 #[test]
 fn test_with_random_value_csv() {
@@ -99,6 +144,22 @@ fn test_with_random_value_csv() {
     });
 }
 
+#[cfg(feature = "csv")]
+#[test]
+fn test_with_random_value_csv_match() {
+    assert_csv_snapshot!(
+        &User {
+            id: 44,
+            username: "julius_csv".to_string(),
+            email: Email("julius@example.com".to_string()),
+            extra: "".to_string(),
+        },
+        match .. {
+            ".id" => "[id]",
+        }
+    );
+}
+
 #[cfg(feature = "ron")]
 #[test]
 fn test_with_random_value_ron() {
@@ -112,6 +173,22 @@ fn test_with_random_value_ron() {
     });
 }
 
+#[cfg(feature = "ron")]
+#[test]
+fn test_with_random_value_ron_match() {
+    assert_ron_snapshot!(
+        &User {
+            id: 53,
+            username: "john_ron".to_string(),
+            email: Email("john@example.com".to_string()),
+            extra: "".to_string(),
+        },
+        match .. {
+            ".id" => "[id]",
+        }
+    );
+}
+
 #[cfg(feature = "toml")]
 #[test]
 fn test_with_random_value_toml() {
@@ -125,6 +202,22 @@ fn test_with_random_value_toml() {
     });
 }
 
+#[cfg(feature = "toml")]
+#[test]
+fn test_with_random_value_toml_match() {
+    assert_toml_snapshot!(
+        &User {
+            id: 53,
+            username: "john_ron".to_string(),
+            email: Email("john@example.com".to_string()),
+            extra: "".to_string(),
+        },
+        match .. {
+            ".id" => "[id]",
+        }
+    );
+}
+
 #[cfg(feature = "json")]
 #[test]
 fn test_with_random_value_json() {
@@ -139,6 +232,23 @@ fn test_with_random_value_json() {
     });
 }
 
+#[cfg(feature = "json")]
+#[test]
+fn test_with_random_value_json_match() {
+    assert_json_snapshot!(
+        &User {
+            id: 9999,
+            username: "jason_doe".to_string(),
+            email: Email("jason@example.com".to_string()),
+            extra: "ssn goes here".to_string(),
+        },
+        match .. {
+            ".id" => "[id]",
+            ".extra" => "[extra]",
+        }
+    );
+}
+
 #[cfg(feature = "json")]
 #[test]
 fn test_with_random_value_json_settings() {
